@@ -888,7 +888,8 @@ void UnpackController::AddMessage(Message::EKind kind, const char* text)
 		m_unpackDecryptError = true;
 	}
 
-	if (m_unpacker == upUnrar && !strncmp(text, "Unrar: The specified password is incorrect.", 43))
+	if (m_unpacker == upUnrar && (!strncmp(text, "Unrar: The specified password is incorrect.", 43) ||
+		!strncmp(text, "Unrar: Incorrect password for", 29)))
 	{
 		m_unpackPasswordError = true;
 	}
