@@ -2,7 +2,7 @@
  *  This file is part of nzbget. See <http://nzbget.net>.
  *
  *  Copyright (C) 2004 Sven Henkel <sidddy@users.sourceforge.net>
- *  Copyright (C) 2007-2017 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ *  Copyright (C) 2007-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -140,6 +140,8 @@ public:
 	void SetSubject(const char* subject) { m_subject = subject; }
 	const char* GetFilename() { return m_filename; }
 	void SetFilename(const char* filename) { m_filename = filename; }
+	void SetOrigname(const char* origname) { m_origname = origname; }
+	const char* GetOrigname() { return m_origname; }
 	void MakeValidFilename();
 	bool GetFilenameConfirmed() { return m_filenameConfirmed; }
 	void SetFilenameConfirmed(bool filenameConfirmed) { m_filenameConfirmed = filenameConfirmed; }
@@ -209,6 +211,7 @@ private:
 	ServerStatList m_serverStats;
 	CString m_subject;
 	CString m_filename;
+	CString m_origname;
 	int64 m_size = 0;
 	int64 m_remainingSize = 0;
 	int64 m_successSize = 0;
@@ -259,11 +262,13 @@ public:
 		cfFailure
 	};
 
-	CompletedFile(int id, const char* filename, EStatus status, uint32 crc, 
-		bool parFile, const char* hash16k, const char* parSetId);
+	CompletedFile(int id, const char* filename, const char* oldname, EStatus status,
+		uint32 crc, bool parFile, const char* hash16k, const char* parSetId);
 	int GetId() { return m_id; }
 	void SetFilename(const char* filename) { m_filename = filename; }
 	const char* GetFilename() { return m_filename; }
+	void SetOrigname(const char* origname) { m_origname = origname; }
+	const char* GetOrigname() { return m_origname; }
 	bool GetParFile() { return m_parFile; }
 	EStatus GetStatus() { return m_status; }
 	uint32 GetCrc() { return m_crc; }
@@ -275,6 +280,7 @@ public:
 private:
 	int m_id;
 	CString m_filename;
+	CString m_origname;
 	EStatus m_status;
 	uint32 m_crc;
 	bool m_parFile;
@@ -446,6 +452,13 @@ public:
 		nkUrl
 	};
 
+	enum EDupeHint
+	{
+		dhNone,
+		dhRedownloadManual,
+		dhRedownloadAuto
+	};
+
 	int GetId() { return m_id; }
 	void SetId(int id);
 	static void ResetGenId(bool max);
@@ -580,6 +593,8 @@ public:
 	void SetDupeScore(int dupeScore) { m_dupeScore = dupeScore; }
 	EDupeMode GetDupeMode() { return m_dupeMode; }
 	void SetDupeMode(EDupeMode dupeMode) { m_dupeMode = dupeMode; }
+	EDupeHint GetDupeHint() { return m_dupeHint; }
+	void SetDupeHint(EDupeHint dupeHint) { m_dupeHint = dupeHint; }
 	uint32 GetFullContentHash() { return m_fullContentHash; }
 	void SetFullContentHash(uint32 fullContentHash) { m_fullContentHash = fullContentHash; }
 	uint32 GetFilteredContentHash() { return m_filteredContentHash; }
@@ -615,7 +630,7 @@ public:
 	void LeavePostProcess();
 	bool IsDupeSuccess();
 	const char* MakeTextStatus(bool ignoreScriptStatus);
-	void AddMessage(Message::EKind kind, const char* text);
+	void AddMessage(Message::EKind kind, const char* text, bool print = true);
 	void PrintMessage(Message::EKind kind, const char* format, ...) PRINTF_SYNTAX(3);
 	int GetMessageCount() { return m_messageCount; }
 	void SetMessageCount(int messageCount) { m_messageCount = messageCount; }
@@ -698,6 +713,7 @@ private:
 	CString m_dupeKey = "";
 	int m_dupeScore = 0;
 	EDupeMode m_dupeMode = dmScore;
+	EDupeHint m_dupeHint = dhNone;
 	uint32 m_fullContentHash = 0;
 	uint32 m_filteredContentHash = 0;
 	FileList m_fileList;
@@ -885,7 +901,7 @@ public:
 	};
 
 	HistoryInfo(std::unique_ptr<NzbInfo> nzbInfo) : m_info(nzbInfo.release()),
-		m_kind(nzbInfo->GetKind() == NzbInfo::nkNzb ? hkNzb : hkUrl) {}
+		m_kind(GetNzbInfo()->GetKind() == NzbInfo::nkNzb ? hkNzb : hkUrl) {}
 	HistoryInfo(std::unique_ptr<DupInfo> dupInfo) : m_info(dupInfo.release()), m_kind(hkDup) {}
 	~HistoryInfo();
 	EKind GetKind() { return m_kind; }
@@ -898,8 +914,8 @@ public:
 	const char* GetName();
 
 private:
-	EKind m_kind;
 	void* m_info;
+	EKind m_kind;
 	time_t m_time = 0;
 };
 
@@ -916,9 +932,15 @@ public:
 		eaNzbAdded,
 		eaNzbDeleted,
 		eaNzbNamed,
+		eaNzbReturned,
 		eaFileCompleted,
 		eaFileDeleted,
-		eaUrlCompleted
+		eaUrlFound,
+		eaUrlAdded,
+		eaUrlDeleted,
+		eaUrlCompleted,
+		eaUrlFailed,
+		eaUrlReturned
 	};
 
 	struct Aspect
@@ -999,6 +1021,7 @@ public:
 	virtual bool EditList(IdList* idList, NameList* nameList, EMatchMode matchMode, EEditAction action, const char* args) = 0;
 	virtual void HistoryChanged() = 0;
 	virtual void Save() = 0;
+	virtual void SaveChanged() = 0;
 	void CalcRemainingSize(int64* remaining, int64* remainingForced);
 
 protected:
