@@ -222,18 +222,11 @@ void WebProcessor::ParseUrl()
 	if (pauth1 && pauth1 < pauth2)
 	{
 		char* pstart = m_url + 1;
-		int len = 0;
-		char* pend = strchr(pstart + 1, '/');
-		if (pend)
-		{
-			len = (int)(pend - pstart < (int)sizeof(m_authInfo) - 1 ? pend - pstart : (int)sizeof(m_authInfo) - 1);
-		}
-		else
-		{
-			len = strlen(pstart);
-		}
+		char* pend = pauth2;
+		int len = std::min((int)(pend - pstart), (int)sizeof(m_authInfo) - 1);
 		strncpy(m_authInfo, pstart, len);
 		m_authInfo[len] = '\0';
+		WebUtil::UrlDecode(m_authInfo);
 		m_url = CString(pend);
 	}
 
@@ -466,8 +459,8 @@ void WebProcessor::SendBodyResponse(const char* body, int bodyLen, const char* c
 		"Access-Control-Allow-Credentials: true\r\n"
 		"Access-Control-Max-Age: 86400\r\n"
 		"Access-Control-Allow-Headers: Content-Type, Authorization\r\n"
-		"Set-Cookie: Auth-Type=%s\r\n"
-		"Set-Cookie: Auth-Token=%s; HttpOnly\r\n"
+		"Set-Cookie: Auth-Type=%s; SameSite=Lax\r\n"
+		"Set-Cookie: Auth-Token=%s; HttpOnly; SameSite=Lax\r\n"
 		"Content-Length: %i\r\n"
 		"%s"					// Content-Type: xxx
 		"%s"					// Content-Encoding: gzip
