@@ -304,10 +304,29 @@ bool FileSystem::AllocateFile(const char* filename, int64 size, bool sparse, CSt
 			errmsg = GetLastErrorMessage();
 			return false;
 		}
-		char c = '0';
-		fwrite(&c, 1, size, file);
+
+		// write zeros in 16K chunks
+		CharBuffer zeros(16 * 1024);
+		memset(zeros, 0, zeros.Size());
+		for (int64 remaining = size; remaining > 0;)
+		{
+			int64 needbytes = std::min(remaining, (int64)zeros.Size());
+			int64 written = fwrite(zeros, 1, needbytes, file);
+			if (written != needbytes)
+			{
+				errmsg = GetLastErrorMessage();
+				fclose(file);
+				return false;
+			}
+			remaining -= written;
+		}
 		fclose(file);
+
 		ok = FileSize(filename) == size;
+		if (!ok)
+		{
+			errmsg = "created file has wrong size";
+		}
 	}
 #endif
 	return ok;
@@ -1020,52 +1039,9 @@ CString FileSystem::WidePathToUtfPath(const wchar_t* wpath)
 #endif
 
 
-#ifdef WIN32
-DirBrowser::DirBrowser(const char* path)
-{
-	BString<1024> mask("%s%c*.*", path, PATH_SEPARATOR);
-	m_file = FindFirstFileW(FileSystem::UtfPathToWidePath(mask), &m_findData);
-	m_first = true;
-}
-
-DirBrowser::~DirBrowser()
-{
-	if (m_file != INVALID_HANDLE_VALUE)
-	{
-		FindClose(m_file);
-	}
-}
-
-const char* DirBrowser::InternNext()
-{
-	bool ok = false;
-	if (m_first)
-	{
-		ok = m_file != INVALID_HANDLE_VALUE;
-		m_first = false;
-	}
-	else
-	{
-		ok = FindNextFileW(m_file, &m_findData) != 0;
-	}
-	if (ok)
-	{
-		m_filename = FileSystem::WidePathToUtfPath(m_findData.cFileName);
-		return m_filename;
-	}
-	return nullptr;
-}
-
-#else
-
-#ifdef DIRBROWSER_SNAPSHOT
 DirBrowser::DirBrowser(const char* path, bool snapshot) :
 	m_snapshot(snapshot)
-#else
-DirBrowser::DirBrowser(const char* path)
-#endif
 {
-#ifdef DIRBROWSER_SNAPSHOT
 	if (m_snapshot)
 	{
 		DirBrowser dir(path, false);
@@ -1076,35 +1052,57 @@ DirBrowser::DirBrowser(const char* path)
 		m_snapshotIter = m_snapshotFiles.begin();
 	}
 	else
-#endif
 	{
+#ifdef WIN32
+		BString<1024> mask("%s%c*.*", path, PATH_SEPARATOR);
+		m_file = FindFirstFileW(FileSystem::UtfPathToWidePath(mask), &m_findData);
+		m_first = true;
+#else
 		m_dir = opendir(path);
+#endif
 	}
 }
 
 DirBrowser::~DirBrowser()
 {
-#ifdef DIRBROWSER_SNAPSHOT
-	if (!m_snapshot)
-#endif
+#ifdef WIN32
+	if (m_file != INVALID_HANDLE_VALUE)
 	{
-		if (m_dir)
-		{
-			closedir(m_dir);
-		}
+		FindClose(m_file);
 	}
+#else
+	if (m_dir)
+	{
+		closedir(m_dir);
+	}
+#endif
 }
 
 const char* DirBrowser::InternNext()
 {
-#ifdef DIRBROWSER_SNAPSHOT
 	if (m_snapshot)
 	{
 		return m_snapshotIter == m_snapshotFiles.end() ? nullptr : **m_snapshotIter++;
 	}
 	else
-#endif
 	{
+#ifdef WIN32
+		bool ok = false;
+		if (m_first)
+		{
+			ok = m_file != INVALID_HANDLE_VALUE;
+			m_first = false;
+		}
+		else
+		{
+			ok = FindNextFileW(m_file, &m_findData) != 0;
+		}
+		if (ok)
+		{
+			m_filename = FileSystem::WidePathToUtfPath(m_findData.cFileName);
+			return m_filename;
+		}
+#else
 		if (m_dir)
 		{
 			m_findData = readdir(m_dir);
@@ -1113,10 +1111,10 @@ const char* DirBrowser::InternNext()
 				return m_findData->d_name;
 			}
 		}
+#endif
 		return nullptr;
 	}
 }
-#endif
 
 const char* DirBrowser::Next()
 {
